==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/LowB/PrimIntegerMul.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v160	((void*)startLabel+40)
#define ST_v159	((void*)startLabel+68)
#define PS_v158	((void*)startLabel+92)
void FR_Prelude_46primIntegerMul(void);
extern Node PM_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v160)
,};
Node FN_Prelude_46primIntegerMul[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_Prelude_46primIntegerMul)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50040
, useLabel(ST_v159)
,	/* CT_v160: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_Prelude_46primIntegerMul[] = {
  CAPTAG(useLabel(FN_Prelude_46primIntegerMul),2)
, useLabel(PS_v158)
, 0
, 0
, 0
,};
Node PP_Prelude_46primIntegerMul[] = {
 };
Node PC_Prelude_46primIntegerMul[] = {
 	/* ST_v159: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,105,109)
, bytes2word(73,110,116,101)
, bytes2word(103,101,114,77)
, bytes2word(117,108,0,0)
,	/* PS_v158: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46primIntegerMul)
, useLabel(PC_Prelude_46primIntegerMul)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "primIntegerMulC" Prelude.primIntegerMul 2 :: Prelude.Integer -> Prelude.Integer -> Prelude.Integer */
extern NodePtr primIntegerMulC(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_primIntegerMulC = {"Prelude","Prelude.primIntegerMul","Prelude.Integer"};
#endif
C_HEADER(FR_Prelude_46primIntegerMul) {
  NodePtr nodeptr;
  NodePtr result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = primIntegerMulC(arg1,arg2);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_primIntegerMulC);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/LowB/PrimIntegerMul.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v163	((void*)startLabel+40)
#define ST_v162	((void*)startLabel+68)
#define PS_v161	((void*)startLabel+92)
void FR_Prelude_46primIntegerMul(void);
extern Node PM_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v163)
,};
Node FN_Prelude_46primIntegerMul[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_Prelude_46primIntegerMul)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v162)
,	/* CT_v163: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_Prelude_46primIntegerMul[] = {
  CAPTAG(useLabel(FN_Prelude_46primIntegerMul),2)
, useLabel(PS_v161)
, 0
, 0
, 0
,};
Node PP_Prelude_46primIntegerMul[] = {
 };
Node PC_Prelude_46primIntegerMul[] = {
 	/* ST_v162: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,105,109)
, bytes2word(73,110,116,101)
, bytes2word(103,101,114,77)
, bytes2word(117,108,0,0)
,	/* PS_v161: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46primIntegerMul)
, useLabel(PC_Prelude_46primIntegerMul)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "primIntegerMulC" Prelude.primIntegerMul 2 :: Prelude.Integer -> Prelude.Integer -> Prelude.Integer */
extern NodePtr primIntegerMulC(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_Prelude_46primIntegerMul = {"Prelude","Prelude.primIntegerMul","Prelude.Integer"};
#endif
C_HEADER(FR_Prelude_46primIntegerMul) {
  NodePtr nodeptr;
  NodePtr result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = primIntegerMulC(arg1,arg2);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_Prelude_46primIntegerMul);
  C_RETURN(nodeptr);
}
